Church Directory Software
=========================
   
Introduction
------------

This program, "churchdir", creates an address book from a spreadsheet file.  The 
address book that is created is an html file which can be put on the Internet 
(a password protected location [1]_ is strongly recommended), or on a local, 
in-house server.  The spreadsheet file contains your lists of addresses.  This 
file is saved in csv format.

The churchdir program was created using the Python programing language and it 
can be run on any computer (Windows, Mac, Linux, etc.) on which Python is 
installed.  Python [2]_ is free to download [3]_ and use.

Python 2.7 or 3.x will work.  3.x is recommended.

Installing
----------

Once Python is installed on your computer (see above) install the Church 
Directory software by executing this command from the command line:
::

  easy_install churchdir

This will download the program from a repository of Python programs from 
pypi.python.org and install it on your computer.

Running the program
-------------------

This program works via the command line.  Create a directory in which to work
and then make it your working directory:
::

  C:\> mkdir mydirectory
  C:\> cd mydirectory

Then execute the program like this:
::

  C:\mydirectory> churchdir-quickstart

You will then be asked a series of questions; most specifically, the name of
the input file.  If the input file doesn't exist, a sample one will be created 
for you. *(You should use this csv file to begin your address list since it 
contains the correct headers.  Use a spreadsheet program to edit.)*

After all the questions are answered, the output file (the address book) is 
created in the current working directory.

Photos
------

Photos, specified in the "Photo URL" column of the input file, should be a head
shot of one person, preferably 96x96 pixels.  A secondary, larger photo may be
specified in the "Photo Secondary" column.  When a user visits the html page 
and if he clicks on the head shot photo, the secondary photo appears.

---------------------------------------------------------------------

.. rubric:: Footnotes

.. [1] How to password protect a directory using .htaccess: 
   `link <http://davidwalsh.name/password-protect-directory-using-htaccess>`_
.. [2] An author of Python tutorial books explains Python: 
   `youtube video <https://www.youtube.com/watch?v=GS84YRHhr_g>`_
.. [3] Download Python: https://www.python.org/downloads/
